@@ -34,7 +34,8 @@ class ExpaiProject:
             return None
 
     def create_model(self, model_path: str = None, is_supervised: bool = True, model_name: str = None,
-                     model_type: str = None, model_library: str = None, model_objective: str = None):
+                     model_type: str = None, model_library: str = None, model_objective: str = None,
+                     model_prediction_type: str = None):
         """
         Create a new model for a project.
         :param model_path: path where your model is stored locally
@@ -47,13 +48,15 @@ class ExpaiProject:
         assert model_type is not None, "Please, indicate the model_type. Refer to documentation for further information"
         assert model_library is not None, "Please, indicate the model_library. Refer to documentation for further information"
         assert model_objective is not None, "Please, indicate the model_objective. Refer to documentation for further information"
+        assert model_prediction_type is not None, "Please, indicate the model_prediction_type. Refer to documentation for further information"
 
 
         data = {"model_name_des": model_name,
                 "is_supervised_flag": 1 if is_supervised else 0,
                 'model_type_des': model_type,
                 'model_library_des': model_library,
-                'model_objective_des': model_objective}
+                'model_objective_des': model_objective,
+                'model_prediction_type_des': model_prediction_type}
 
         files = {'model_file': open(model_path, 'rb')}
         headers = {'api_key': self.api_key}
